0.1.1 (15/08/2013)
-------------------

* Fix ``slice-image`` script.
* Rename ``join_tiles()`` to ``join()``.

0.1.0 (12/08/2013)
-------------------

* New ``Tile`` class.
* ``split_image()`` now saves tiles by default.
* ``get_basename()`` can now handle paths.
* More comprehensive validation in ``validate_image()``.
* Fix incorrect filenames returned by ``save_tiles()``.
* Expand documentation.
* Improve test coverage.

0.0.2 (07/23/2013)
------------------

* Fix dependencies in setup.py

0.0.1 (07/19/2013)
------------------

* Initial release.

